==> hlw-core-0.0.2-20250422.075438-9-sources.jar: cn/gtmap/hlw/core/model/GxYyJjr.java <==
package cn.gtmap.hlw.core.model;

import com.baomidou.mybatisplus.extension.activerecord.Model;

import java.io.Serializable;

/**
 * (GxYyJjr)表实体类
 *
 * @author makejava
 * @since 2024-02-23 16:59:35
 */
@SuppressWarnings("serial")
public class GxYyJjr extends Model<GxYyJjr> {
    /**
     * 主键
     */
    private String id;

    /**
     * 节假日（yyyyMMdd）
     */
    private String jjr;

    /**
     * 年份
     */
    private String nf;

    /**
     * 日期（必填）
     */
    private String rq;

    /**
     * 星期（必填 星期一、二。。。星期日）
     */
    private String xq;

    /**
     * 是否工作日（0：否，1：是）
     */
    private String sfgzr;

    /**
     * 登记中心代码（gx_yy_djzx.djzxdm）
     */
    private String djzxdm;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjr() {
        return jjr;
    }

    public void setJjr(String jjr) {
        this.jjr = jjr;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public String getRq() {
        return rq;
    }

    public void setRq(String rq) {
        this.rq = rq;
    }

    public String getXq() {
        return xq;
    }

    public void setXq(String xq) {
        this.xq = xq;
    }

    public String getSfgzr() {
        return sfgzr;
    }

    public void setSfgzr(String sfgzr) {
        this.sfgzr = sfgzr;
    }

    public String getDjzxdm() {
        return djzxdm;
    }

    public void setDjzxdm(String djzxdm) {
        this.djzxdm = djzxdm;
    }

    /**
     * 获取主键值
     *
     * @return 主键值
     */
    @Override
    protected Serializable pkVal() {
        return this.id;
    }
}

==> hlw-core-0.0.2-20250711.025037-103-sources.jar: cn/gtmap/hlw/core/model/GxYyJjr.java <==
package cn.gtmap.hlw.core.model;

import com.baomidou.mybatisplus.extension.activerecord.Model;

import java.io.Serializable;

/**
 * (GxYyJjr)表实体类
 *
 * @author makejava
 * @since 2024-02-23 16:59:35
 */
@SuppressWarnings("serial")
public class GxYyJjr extends Model<GxYyJjr> {
    /**
     * 主键
     */
    private String id;

    /**
     * 节假日（yyyyMMdd）
     */
    private String jjr;

    /**
     * 年份
     */
    private String nf;

    /**
     * 日期（必填）
     */
    private String rq;

    /**
     * 星期（必填 星期一、二。。。星期日）
     */
    private String xq;

    /**
     * 是否工作日（0：否，1：是）
     */
    private String sfgzr;

    /**
     * 登记中心代码（gx_yy_djzx.djzxdm）
     */
    private String djzxdm;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjr() {
        return jjr;
    }

    public void setJjr(String jjr) {
        this.jjr = jjr;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public String getRq() {
        return rq;
    }

    public void setRq(String rq) {
        this.rq = rq;
    }

    public String getXq() {
        return xq;
    }

    public void setXq(String xq) {
        this.xq = xq;
    }

    public String getSfgzr() {
        return sfgzr;
    }

    public void setSfgzr(String sfgzr) {
        this.sfgzr = sfgzr;
    }

    public String getDjzxdm() {
        return djzxdm;
    }

    public void setDjzxdm(String djzxdm) {
        this.djzxdm = djzxdm;
    }

    /**
     * 获取主键值
     *
     * @return 主键值
     */
    @Override
    public Serializable pkVal() {
        return this.id;
    }
}
